(bgs)=

# Background selection

The following example recreates results from:

```
Hudsonn, R. R., and N. L. Kaplan. 1995. “Deleterious Background Selection with Recombination.” Genetics 141 (4): 1605–17.
```

```{literalinclude} ../../examples/bgs/bgs.py

```


